# lyse

lyse is an analysis framework. It coordinates the running of python analysis scripts on experiment data as it becomes availiable, updating plots in real time.

([view on Github](https://github.com/labscript-suite/lyse))

